mEvent class

Constructors

mEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAll() → void
executeModuleEvent(String moduleName, int eventID, String uuid, Map<String, dynamic> data) → void
putEventListen(String moduleName, int eventID, EventCallback callback) → void
removeEventListen(String module, int eventID) → void
removeModule(String module) → void